import 'package:flutter/material.dart';
import 'package:memri/core/cvu/constants/cvu_color.dart';
import 'package:memri/core/cvu/widgets/components/cvu_ui_node_resolver.dart';
import 'package:memri/widgets/components/shapes/circle.dart';

/// A CVU element for displaying a circle
class CVUShapeCircle extends StatefulWidget {
  final CVUUINodeResolver nodeResolver;

  const CVUShapeCircle({Key? key, required this.nodeResolver})
      : super(key: key);

  @override
  CVUShapeCircleState createState() => CVUShapeCircleState();
}

class CVUShapeCircleState extends State<CVUShapeCircle> {
  late Color color;

  @override
  initState() {
    super.initState();
    init();
  }

  @override
  void didUpdateWidget(oldWidget) {
    super.didUpdateWidget(oldWidget);
    setState(() => init());
  }

  void init() {
    color = widget.nodeResolver.propertyResolver.color() ??
        CVUColor.system('clear');
  }

  @override
  Widget build(BuildContext context) {
    return Circle(color: color);
  }
}

/// A CVU element for displaying a rectangle
class CVUShapeRectangle extends StatefulWidget {
  final CVUUINodeResolver nodeResolver;

  const CVUShapeRectangle({Key? key, required this.nodeResolver})
      : super(key: key);

  @override
  CVUShapeRectangleState createState() => CVUShapeRectangleState();
}

class CVUShapeRectangleState extends State<CVUShapeRectangle> {
  late double cornerRadius;

  late Color color;

  @override
  initState() {
    super.initState();
    init();
  }

  @override
  void didUpdateWidget(oldWidget) {
    super.didUpdateWidget(oldWidget);
    setState(() => init());
  }

  void init() {
    cornerRadius = widget.nodeResolver.propertyResolver.cornerRadius;
    color = widget.nodeResolver.propertyResolver.color() ??
        CVUColor.system('clear');
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: BoxDecoration(
        borderRadius: BorderRadius.all(Radius.circular(cornerRadius)),
        color: color,
      ),
    );
  }
}
