import 'package:memri/core/apis/gitlab_api.dart';
import 'package:memri/core/models/pipeline_job.dart';
import 'package:memri/core/services/api_service.dart';

class GitlabService extends ApiService<GitlabAPI> {
  GitlabService() : super(api: GitlabAPI());

  String? get accessToken => api.accessToken;

  String? get refreshToken => api.refreshToken;

  void setTokens(String? accessToken, String? refreshToken) =>
      api.setTokens(accessToken, refreshToken);

  Future<String> getTextFileContent({
    required String filepath,
    int? projectId,
    String? projectPath,
    String branch = 'main',
  }) =>
      api
          .getTextFile(
              projectId: projectId,
              projectPath: projectPath,
              filepath: filepath,
              branch: branch)
          .catchError((error) => '');

  Future<String> downloadSingleArtifact({
    required int gitProjectId,
    required String filename,
    required String jobName,
    String? branch,
  }) =>
      api
          .downloadSingleArtifact(
              gitProjectId: gitProjectId,
              filename: filename,
              jobName: jobName,
              branch: branch)
          .catchError((error) => '');

  Future<Map<String, dynamic>> getUser() => api.getUser();

  Future<int?> getUserId() async => (await getUser())['id'];

  Future<dynamic> getUserProjects() async =>
      api.getUserProjects(await getUserId());

  Future<dynamic> getProjectPackages(int projectId) async =>
      api.getProjectPackages(projectId);

  Future<int?> getLastPipelineId(dynamic projectId) async =>
      api.getLastPipelineId(projectId);

  Future<dynamic> getJobsJson(dynamic projectId, dynamic pipelineId) async =>
      api.getJobsJson(projectId, pipelineId);

  Future<dynamic> getUserProject(String projectName) async {
    var userProjects = await getUserProjects();
    for (var project in userProjects) {
      if ((project['name']) == projectName) {
        // AppLogger.debug(
        //     'PROJECT ${JsonEncoder.withIndent(' ').convert(project)}');
        return project;
      }
    }
    return null;
  }

  Future<bool> projectHasModelPackage(int projectId) async {
    var packages = await getProjectPackages(projectId);
    return packages.isNotEmpty;
  }

  // Future<int?> triggerPipeline(int projectId) async {
  //   var url = Uri.parse(api_url + "/projects/$projectId/pipeline");
  //   var response = await http.get(url, headers: getHeader());
  //   return jsonDecode(response.body)[0]["id"] ?? null;
  // }

  Future<List<PipelineJob>> getPipelineJobs(dynamic projectId) async {
    var pipelineId = await getLastPipelineId(projectId);
    if (pipelineId == null) {
      return [];
    }
    var jobsJson = await getJobsJson(projectId, pipelineId);

    List<PipelineJob> jobs = [];
    for (var jobJson in jobsJson) {
      jobs.add(PipelineJob(
          name: jobJson['name'],
          status: jobJson['status'],
          url: jobJson['web_url']));
    }
    return jobs;
  }

  String stringToGitlabSlug(String s) {
    // Copied from gitlab 'sluggify' function
    // Source: https://gitlab.com/gitlab-org/gitlab/-/blob/master/lib/gitlab/utils.rb#L92
    String slug = s.toLowerCase();
    slug = slug.replaceAllMapped(RegExp(r'[^a-z0-9]'), (match) => '-');
    slug = slug.replaceAllMapped(RegExp(r'(^-+|-+$)'), (match) => '');
    return slug;
  }

  bool isValidGitlabSlug(String s) {
    return (s == stringToGitlabSlug(s));
  }
}
