import 'package:flutter/material.dart';
import 'package:memri/core/models/running_plugin.dart';
import 'package:memri/providers/data_app_provider.dart';
import 'package:memri/providers/navigation_provider.dart';
import 'package:memri/utilities/helpers/app_helper.dart';
import 'package:memri/widgets/data_app/data_app.dart';
import 'package:memri/widgets/data_app/data_app_error.dart';
import 'package:memri/widgets/data_app/data_app_logs.dart';
import 'package:memri/widgets/data_app/data_app_settings.dart';
import 'package:memri/widgets/loading_indicator.dart';
import 'package:memri/widgets/navigation/top_bar.dart';
import 'package:memri/widgets/scaffold/workspace_scaffold.dart';
import 'package:provider/provider.dart';

class AppsConfigureScreen extends StatefulWidget {
  const AppsConfigureScreen({Key? key, required this.tab, required this.id})
      : super(key: key);

  final String tab;
  final String id;

  @override
  State<AppsConfigureScreen> createState() => _AppsConfigureScreenState();
}

class _AppsConfigureScreenState extends State<AppsConfigureScreen> {
  RunningPlugin? runningPlugin;

  late final _dataAppProvider =
      Provider.of<DataAppProvider>(context, listen: false);
  late final _navProvider =
      Provider.of<NavigationProvider>(context, listen: false);
  late List<TabItem> tabs = [
    TabItem(
        name: runningPlugin?.plugin.get('name') ?? 'Data App',
        onTap: () =>
            _dataAppProvider.setAppState(runningPlugin, AppState.showApp)),
    TabItem(
        name: 'Settings',
        onTap: () =>
            _dataAppProvider.setAppState(runningPlugin, AppState.showSettings)),
    TabItem(
        name: 'Logs',
        onTap: () =>
            _dataAppProvider.setAppState(runningPlugin, AppState.showLogs)),
  ];

  @override
  void initState() {
    runningPlugin = _dataAppProvider.getRunningPlugin(widget.id);
    if (widget.tab == AppState.showSettings.toUrlString()) {
      runningPlugin?.appState = AppState.showSettings;
      _navProvider.setSelectedTabIndex(1);
    } else if (widget.tab == AppState.showLogs.toUrlString()) {
      runningPlugin?.appState = AppState.showLogs;
      _navProvider.setSelectedTabIndex(2);
    } else {
      runningPlugin?.appState = AppState.showApp;
      _navProvider.setSelectedTabIndex(0);
    }

    super.initState();
  }

  void _updateTabs() {
    if (widget.tab == AppState.showSettings.toUrlString()) {
      runningPlugin?.appState = AppState.showSettings;
    } else if (widget.tab == AppState.showLogs.toUrlString()) {
      runningPlugin?.appState = AppState.showLogs;
    } else {
      runningPlugin?.appState = AppState.showApp;
    }
  }

  @override
  void didUpdateWidget(covariant AppsConfigureScreen oldWidget) {
    if (runningPlugin == null) {
      _dataAppProvider.updateRunningPlugin(widget.id);
      runningPlugin = _dataAppProvider.getRunningPlugin(widget.id);
    }
    super.didUpdateWidget(oldWidget);
  }

  @override
  Widget build(BuildContext context) {
    return WorkspaceScaffold(
      currentItem: NavigationItem.apps,
      backgroundColor: app.colors.white,
      tabs: tabs,
      child: Consumer<DataAppProvider>(
        builder: (context, dataAppProvider, _) {
          if (runningPlugin == null) {
            _dataAppProvider.updateRunningPlugin(widget.id);
            runningPlugin = _dataAppProvider.getRunningPlugin(widget.id);
          }
          if (runningPlugin == null) return DataAppError();
          if (runningPlugin!.appState == AppState.loading) _updateTabs();

          switch (runningPlugin!.appState) {
            case AppState.loading:
              return LoadingIndicator();
            case AppState.showApp:
              return DataApp(
                runningPlugin: runningPlugin,
                id: widget.id,
              );
            case AppState.showLogs:
              return DataAppLogs(currentRunLog: runningPlugin?.runLog);
            case AppState.showSettings:
              return DataAppSettings(runningPlugin: runningPlugin);
          }
        },
      ),
    );
  }
}
