import 'package:flutter/material.dart';
import 'package:memri/constants/app_styles.dart';
import 'package:memri/core/models/item.dart';
import 'package:memri/providers/data_app_provider.dart';
import 'package:memri/utilities/helpers/app_helper.dart';
import 'package:memri/widgets/scaffold/workspace_scaffold.dart';
import 'package:provider/provider.dart';

class AppsFeedScreen extends StatefulWidget {
  final bool showMainNavigation;

  // final String? importer;

  const AppsFeedScreen({Key? key, this.showMainNavigation = true})
      : super(key: key);

  @override
  _AppsFeedScreenState createState() => _AppsFeedScreenState();
}

class _AppsFeedScreenState extends State<AppsFeedScreen> {
  late final _dataAppProvider =
      Provider.of<DataAppProvider>(context, listen: false);
  int selectedFeedItem = 0;
  Item? activeFeedItem;
  late final feedFocus = FocusNode();

  @override
  void initState() {
    _dataAppProvider.getFeed();
    super.initState();
  }

  @override
  void dispose() {
    _dataAppProvider.feedStreamSubscription?.cancel();
    feedFocus.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return WorkspaceScaffold(
      currentItem: NavigationItem.apps,
      child: Consumer<DataAppProvider>(
        builder: (context, provider, _) {
          return Container(
            width: MediaQuery.of(context).size.width,
            padding: EdgeInsets.fromLTRB(30, 30, 0, 30),
            child: Row(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Expanded(
                  flex: 2,
                  child: Container(
                    decoration: BoxDecoration(
                        border: Border(
                            right: BorderSide(
                                width: 1.0, color: app.colors.brandLineGrey))),
                    child: ListView.builder(
                      controller: ScrollController(),
                      itemCount: provider.feed.length,
                      shrinkWrap: true,
                      itemBuilder: (context, index) {
                        ImageProvider? image = provider.tweetImageProviders[
                            provider.feed[index].get('id')];
                        return InkWell(
                          hoverColor: selectedFeedItem == index
                              ? app.colors.greyLight
                              : app.colors.white,
                          focusColor: selectedFeedItem == index
                              ? app.colors.greyLight
                              : app.colors.white,
                          onTap: () {
                            setState(() {
                              selectedFeedItem = index;
                            });
                            Item? feedItem = provider.feed[index];
                            setActiveFeedItem(feedItem: feedItem);
                          },
                          child: Container(
                            decoration: BoxDecoration(
                                border: Border(
                                    bottom: BorderSide(
                                        width: 1.0,
                                        color: app.colors.brandLineGrey))),
                            padding: EdgeInsets.fromLTRB(15, 15, 15, 15),
                            child: Column(
                              mainAxisSize: MainAxisSize.min,
                              children: [
                                Row(
                                  children: [
                                    Flexible(
                                      child: ListTile(
                                        leading: CircleAvatar(
                                            radius: 16.0,
                                            backgroundImage:
                                                // chats_images.elementAt(index) == null ? Image.asset('assets/images/person.png'): Image(image: chats_images[index]!),
                                                // chatImageUrls.length > index &&
                                                //         chatImageUrls[index] != null
                                                //     ? chatImageUrls[index]!
                                                image ??
                                                    AssetImage(
                                                        'assets/images/person.png'),
                                            backgroundColor:
                                                Colors.transparent),
                                        title: Text(
                                            provider.getFeedAuthorName(index)),
                                        subtitle: Text('@' +
                                            provider
                                                .getFeedAuthorHandle(index)),
                                        trailing: Row(
                                          mainAxisSize: MainAxisSize.min,
                                          children: [
                                            Text(provider
                                                .getFeedPostDate(index)),
                                            IconButton(
                                              onPressed: () {},
                                              icon: Icon(Icons.more_horiz,
                                                  color: Color(0xFFDFDEDE)),
                                            ),
                                          ],
                                        ),
                                      ),
                                    ),
                                  ],
                                ),
                                Row(
                                  crossAxisAlignment: CrossAxisAlignment.start,
                                  mainAxisAlignment: MainAxisAlignment.start,
                                  children: [
                                    Flexible(
                                      flex: 3,
                                      child: Container(
                                        padding:
                                            EdgeInsets.fromLTRB(15, 15, 15, 15),
                                        child: Text(
                                            provider.feed[index]
                                                    .get('message') ??
                                                '',
                                            style: AppStyles.bodyText1),
                                      ),
                                    ),
                                    Spacer(),
                                    Container(
                                      child: app.icons.twitter(
                                          height: 20, color: Color(0xff1D9BEF)),
                                    ),
                                  ],
                                ),
                              ],
                            ),
                          ),
                        );
                      },
                    ),
                  ),
                ),
                Flexible(child: SizedBox(height: 1), flex: 3)
              ],
            ),
          );
        },
      ),
    );
  }

  void setActiveFeedItem({required feedItem}) async {
    // Reset active messages while waiting for query
    setState(() {
      activeFeedItem = feedItem;
    });
  }
}
