import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:memri/configs/routes/route_navigator.dart';
import 'package:memri/constants/app_styles.dart';
import 'package:memri/providers/navigation_provider.dart';
import 'package:memri/utilities/helpers/app_helper.dart';
import 'package:memri/utilities/helpers/responsive_helper.dart';
import 'package:memri/widgets/scaffold/workspace_scaffold.dart';
import 'package:provider/provider.dart';

class ImporterCreateScreen extends StatefulWidget {
  const ImporterCreateScreen({Key? key}) : super(key: key);

  @override
  State<ImporterCreateScreen> createState() => _ImporterCreateScreenState();
}

class _ImporterCreateScreenState extends State<ImporterCreateScreen> {
  late final _navigationProvider =
      Provider.of<NavigationProvider>(context, listen: false);

  @override
  Widget build(BuildContext context) {
    return WorkspaceScaffold(
      currentItem: NavigationItem.data,
      child: SingleChildScrollView(
        child: Container(
          width: MediaQuery.of(context).size.width,
          padding: const EdgeInsets.all(30),
          child: Column(
            mainAxisAlignment: MainAxisAlignment.start,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              if (!ResponsiveHelper(context).isSmallScreen)
                SizedBox(height: 16),
              Text('Creating importers', style: AppStyles.headline2),
              SizedBox(height: 22),
              RichText(
                text: TextSpan(
                  children: [
                    TextSpan(
                      text:
                          'To learn more about how to create an importer plugin, visit ',
                      style: AppStyles.buttonLabel
                          .copyWith(color: app.colors.brandBlack),
                    ),
                    TextSpan(
                      text: 'Plugin documentation page',
                      style: AppStyles.buttonLabel
                          .copyWith(color: app.colors.brandOrange),
                      recognizer: TapGestureRecognizer()
                        ..onTap = _navigationProvider.openPluginDocLink,
                    ),
                    TextSpan(
                      text: '.',
                      style: AppStyles.buttonLabel
                          .copyWith(color: app.colors.brandBlack),
                    ),
                  ],
                ),
              ),
              SizedBox(height: 12),
              RichText(
                text: TextSpan(
                  children: [
                    TextSpan(
                      text:
                          'If you have any questions or wish to discuss this feature, please message us on ',
                      style: AppStyles.buttonLabel
                          .copyWith(color: app.colors.brandBlack),
                    ),
                    TextSpan(
                      text: 'Plugin channel on Discord',
                      style: AppStyles.buttonLabel
                          .copyWith(color: app.colors.brandOrange),
                      recognizer: TapGestureRecognizer()
                        ..onTap = _navigationProvider.openDiscordPluginLink,
                    ),
                    TextSpan(
                      text: ', we’ll be glad to hear from you!',
                      style: AppStyles.buttonLabel
                          .copyWith(color: app.colors.brandBlack),
                    ),
                  ],
                ),
              ),
              SizedBox(height: 70),
              Row(
                children: [
                  TextButton(
                    onPressed: () => RouteNavigator.navigateBack(context),
                    style: secondaryButtonStyle,
                    child: SizedBox(
                      height: 36,
                      child: Row(
                        children: [
                          app.icons.back(color: app.colors.brandOrange),
                          SizedBox(width: 10),
                          Text('Back to data screen'),
                        ],
                      ),
                    ),
                  ),
                ],
              ),
            ],
          ),
        ),
      ),
    );
  }
}
