import 'package:flutter/material.dart';
import 'package:memri/configs/routes/route_navigator.dart';
import 'package:memri/constants/app_styles.dart';
import 'package:memri/providers/importer_provider.dart';
import 'package:memri/utilities/extensions/string.dart';
import 'package:memri/utilities/helpers/app_helper.dart';
import 'package:memri/widgets/scaffold/workspace_scaffold.dart';
import 'package:provider/provider.dart';

class ImporterDownloadingScreen extends StatefulWidget {
  const ImporterDownloadingScreen(
      {Key? key, required this.id, required this.name})
      : super(key: key);

  final String id;
  final String name;

  @override
  State<ImporterDownloadingScreen> createState() =>
      _ImporterDownloadingScreenState();
}

class _ImporterDownloadingScreenState extends State<ImporterDownloadingScreen> {
  late final importerProvider =
      Provider.of<ImporterProvider>(context, listen: false);

  @override
  void initState() {
    importerProvider.initDownloadingStreams(widget.id, widget.name);
    super.initState();
  }

  @override
  void dispose() {
    importerProvider.cancelDownloadingStreamSub(widget.name);
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return WorkspaceScaffold(
      currentItem: NavigationItem.data,
      child: Consumer<ImporterProvider>(
        builder: (context, provider, _) {
          return Container(
            padding: EdgeInsets.symmetric(vertical: 64, horizontal: 64),
            child: Column(
              mainAxisAlignment: MainAxisAlignment.start,
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Row(
                  children: [
                    Text('Success!',
                        style: TextStyle(
                            fontSize: 12, color: app.colors.brandBlack)),
                  ],
                ),
                SizedBox(height: 8),
                Row(
                  children: [
                    Text(
                      'Your ${widget.name.capitalize()} is syncing...',
                      style: AppStyles.headline1
                          .copyWith(color: app.colors.brandBlack),
                    ),
                  ],
                ),
                SizedBox(height: 8),
                Text(
                  '${widget.name.capitalize()} has successfully connected to your POD. Your data is being imported, this may take a while.\nYou can navigate away from this screen while your data is importing.',
                  style:
                      TextStyle(fontSize: 14, color: app.colors.brandGreyText),
                ),
                SizedBox(height: 64),
                Row(
                  crossAxisAlignment: CrossAxisAlignment.end,
                  children: [
                    Text('Uploading ${widget.name.capitalize()} data:',
                        style: TextStyle(
                            fontSize: 14, color: app.colors.brandBlack)),
                    SizedBox(width: 10),
                    Builder(builder: (context) {
                      return Text(
                          (provider.progress[widget.name] == null
                              ? 'starting'
                              : '${(provider.progress[widget.name]! * 100.0).toStringAsFixed(0)}%'),
                          style: TextStyle(
                              fontSize: 30, color: app.colors.brandViolet));
                    }),
                  ],
                ),
                SizedBox(height: 64),
                Wrap(
                  children: [
                    TextButton(
                      onPressed: () => RouteNavigator.navigateTo(
                          context: context, route: Routes.projects),
                      style: primaryButtonStyle,
                      child: SizedBox(
                        height: 36,
                        child: Row(
                          mainAxisSize: MainAxisSize.min,
                          children: const [Text('Create a new project')],
                        ),
                      ),
                    ),
                    SizedBox(width: 30),
                    TextButton(
                      onPressed: () => RouteNavigator.navigateBack(context),
                      style: secondaryButtonStyle,
                      child: SizedBox(
                        height: 36,
                        child: Row(
                          mainAxisSize: MainAxisSize.min,
                          children: const [Text('Back to data screen')],
                        ),
                      ),
                    ),
                  ],
                ),
              ],
            ),
          );
        },
      ),
    );
  }
}
