import 'package:flutter/material.dart';
import 'package:memri/constants/app_styles.dart';
import 'package:memri/providers/oauth_provider.dart';
import 'package:memri/utilities/extensions/string.dart';
import 'package:memri/utilities/helpers/app_helper.dart';
import 'package:provider/provider.dart';

class OauthScreen extends StatefulWidget {
  final bool showMainNavigation;

  const OauthScreen({Key? key, this.showMainNavigation = true})
      : super(key: key);

  @override
  OauthScreenState createState() => OauthScreenState();
}

class OauthScreenState extends State<OauthScreen> {
  @override
  void initState() {
    Provider.of<OAuthProvider>(context, listen: false).init();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        body: Consumer<OAuthProvider>(
      builder: (context, provider, _) => Container(
        width: MediaQuery.of(context).size.width,
        padding: EdgeInsets.all(30),
        child: Center(
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.center,
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              Row(
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  Column(
                    mainAxisAlignment: MainAxisAlignment.center,
                    children: [
                      app.images.logoSquare(height: 50),
                      SizedBox(height: 5),
                      Text('Memri', style: AppStyles.bodyBold),
                    ],
                  ),
                  SizedBox(width: 30),
                  app.icons.arrowRight(color: app.colors.brandBlack),
                  SizedBox(width: 30),
                  if (provider.service == 'gitlab')
                    Column(
                      children: [
                        app.icons.gitlab(height: 50),
                        SizedBox(height: 5),
                        Text('Gitlab', style: AppStyles.bodyBold),
                      ],
                    ),
                  if (provider.service == 'twitter')
                    Column(
                      children: [
                        app.icons.twitter(height: 50, color: Color(0xff1D9BEF)),
                        SizedBox(height: 5),
                        Text('Twitter', style: AppStyles.bodyBold),
                      ],
                    ),
                ],
              ),
              SizedBox(height: 20),
              Text(
                'Authorize ${(provider.service).capitalize()}',
                style: AppStyles.headline1,
              ),
              SizedBox(height: 5),
              Text(
                'Memri wants access to your ${provider.service.capitalize()} account',
                style: AppStyles.bodyText1,
              ),
              SizedBox(height: 70),
              Text(
                provider.responseMessage,
                style: AppStyles.headline3,
                textAlign: TextAlign.center,
              ),
            ],
          ),
        ),
      ),
    ));
  }
}
