import 'dart:async';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:memri/constants/app_styles.dart';
import 'package:memri/localization/generated/l10n.dart';
import 'package:memri/providers/pod_provider.dart';
import 'package:memri/utilities/helpers/app_helper.dart';
import 'package:memri/utilities/helpers/responsive_helper.dart';
import 'package:memri/widgets/scaffold/workspace_scaffold.dart';
import 'package:provider/provider.dart';

class PodKeysScreen extends StatelessWidget {
  const PodKeysScreen({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return WorkspaceScaffold(
      currentItem: NavigationItem.workspace,
      backgroundColor: app.colors.white,
      child: Consumer<PodProvider>(builder: (context, provider, child) {
        return SingleChildScrollView(
          child: Padding(
            padding: const EdgeInsets.symmetric(horizontal: 30),
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                SizedBox(height: 20),
                if (!ResponsiveHelper(context).isSmallScreen)
                  SizedBox(height: 20),
                Text(
                  'Your POD crypto keys',
                  style: AppStyles.headline1,
                ),
                SizedBox(height: 10),
                Text(
                  'These are your personal crypto keys. Keep them in a safe place.\nYou will need your keys to log into your account. If you lose your keys, you will not be able to recover them and you will permanently lose access to your account and POD.',
                  style: AppStyles.bodyText1
                      .copyWith(color: app.colors.brandGreyText),
                ),
                SizedBox(height: 20),
                Divider(),
                Text(
                  'Your owner key'.toUpperCase(),
                  style: AppStyles.smallCaps.copyWith(color: Color(0xff828282)),
                ),
                SizedBox(height: 3),
                SelectableText(
                  provider.ownerKey,
                  style: AppStyles.bodyText1.copyWith(color: Color(0xffE9500F)),
                ),
                Divider(),
                Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    SizedBox(height: 8),
                    Text(
                      'Your database key'.toUpperCase(),
                      style: AppStyles.smallCaps
                          .copyWith(color: Color(0xff828282)),
                    ),
                    SizedBox(height: 3),
                    SelectableText(
                      provider.databaseKey,
                      style: AppStyles.bodyText1
                          .copyWith(color: Color(0xffE9500F)),
                    ),
                    SizedBox(height: 14),
                    TextButton(
                      onPressed: () {
                        Clipboard.setData(ClipboardData(
                            text:
                                '${S.current.login_key}: ${provider.ownerKey}\n${S.current.password_key}: ${provider.databaseKey}'));
                        provider.handleKeysMessageVisibility(true);
                        Future.delayed(
                          Duration(seconds: 3),
                          () => provider.handleKeysMessageVisibility(false),
                        );
                      },
                      style: primaryButtonStyle,
                      child: SizedBox(
                        height: 36,
                        child: Row(
                          mainAxisSize: MainAxisSize.min,
                          children: [
                            Text(
                              'Copy Keys',
                              style: AppStyles.buttonLabel
                                  .copyWith(color: Colors.white),
                            ),
                            SizedBox(width: 10),
                            app.icons.copyToClipboard(color: Colors.white),
                          ],
                        ),
                      ),
                    ),
                    SizedBox(height: 16),
                    if (provider.keyVisibility)
                      Container(
                        width: 632,
                        decoration: BoxDecoration(
                          color: app.colors.greyBackGround,
                          border: Border.all(color: app.colors.brandGreen),
                        ),
                        padding:
                            EdgeInsets.symmetric(horizontal: 10, vertical: 15),
                        child: Text(
                          'You saved the keys successfully!',
                          style: AppStyles.bodyText1
                              .copyWith(color: app.colors.brandGreen),
                        ),
                      ),
                  ],
                ),
              ],
            ),
          ),
        );
      }),
    );
  }
}
