import 'package:flutter/material.dart';
import 'package:memri/constants/app_styles.dart';
import 'package:memri/core/models/item.dart';
import 'package:memri/providers/project_provider.dart';
import 'package:memri/utilities/helpers/app_helper.dart';
import 'package:memri/utilities/helpers/responsive_helper.dart';
import 'package:memri/widgets/project/project_progress_bar.dart';
import 'package:memri/widgets/scaffold/workspace_scaffold.dart';
import 'package:provider/provider.dart';

class ProjectsLabelDataScreen extends StatefulWidget {
  const ProjectsLabelDataScreen({Key? key, required this.id}) : super(key: key);
  final String id;

  @override
  State<ProjectsLabelDataScreen> createState() =>
      _ProjectsLabelDataScreenState();
}

class _ProjectsLabelDataScreenState extends State<ProjectsLabelDataScreen> {
  final FocusNode _focusNode = FocusNode();

  @override
  void initState() {
    Provider.of<ProjectProvider>(context, listen: false)
        .setCurrentProject(context, widget.id, resetState: false);
    super.initState();
  }

  @override
  void dispose() {
    _focusNode.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return WorkspaceScaffold(
      currentItem: NavigationItem.projects,
      backgroundColor: app.colors.white,
      child: ProjectProgressBar(
        currentStep: 1,
        summary:
            !ResponsiveHelper(context).isSmallScreen ? _buildSummary() : null,
        child: _buildBody(),
      ),
    );
  }

  Widget _buildBody() {
    var greenStyle = TextStyle(
      color: app.colors.brandGreen,
      fontSize: 14,
      fontWeight: FontWeight.w400,
    );
    return Consumer<ProjectProvider>(
      builder: (context, provider, _) {
        return Container(
          color: app.colors.white,
          padding: EdgeInsets.symmetric(horizontal: 30),
          child: Column(
            children: [
              SizedBox(height: 20),
              if (!ResponsiveHelper(context).isSmallScreen)
                SizedBox(height: 20),
              _buildTitleTile(provider),
              if (provider.showInfo) SizedBox(height: 20),
              if (provider.showInfo)
                Container(
                  padding: EdgeInsets.all(16),
                  width: double.infinity,
                  color: Color.fromARGB(10, 33, 192, 164),
                  child: Stack(
                    children: [
                      Positioned(
                        top: 0,
                        right: 0,
                        child: InkWell(
                          onTap: (() => provider.toggleShowInfo()),
                          child: app.icons.x(
                              color: app.colors.brandGreen,
                              height: 20,
                              width: 20),
                        ),
                      ),
                      Column(
                        crossAxisAlignment: CrossAxisAlignment.start,
                        children: [
                          Text(
                            'You don’t need to label entire dataset upfront, though accurately labeled data will increase your model’s accuracy.',
                            style: greenStyle,
                          ),
                          SizedBox(
                            height: 8,
                          ),
                          Text(
                              'Once you feel you have labeled enough to train the model, quit labelling and move to next step.',
                              style: greenStyle),
                        ],
                      ),
                    ],
                  ),
                ),
              SizedBox(height: 20),
              _buildLabeler(provider),
              if (ResponsiveHelper(context).isSmallScreen) SizedBox(height: 30),
              if (ResponsiveHelper(context).isSmallScreen) _buildSummary(),
              SizedBox(height: 20),
              if (!ResponsiveHelper(context).isSmallScreen)
                SizedBox(height: 20),
            ],
          ),
        );
      },
    );
  }

  Widget _buildLabeler(ProjectProvider provider) {
    return !ResponsiveHelper(context).isSmallScreen
        ? Expanded(
            child: Stack(
              children: [
                Positioned(
                  top: 0,
                  left: 0,
                  right: 0,
                  bottom: 0,
                  child: Container(color: app.colors.greyBackGround),
                ),
                Positioned(
                  top: 30,
                  left: 125,
                  right: 125,
                  bottom: 70,
                  child: SingleChildScrollView(
                    child: SizedBox(
                      width: MediaQuery.of(context).size.width,
                      child: Center(
                        child: Text(
                          provider.getCurrentContent(),
                          style: AppStyles.headline1,
                          // maxLines: 5,
                        ),
                      ),
                    ),
                  ),
                ),
                Positioned(
                  left: 5,
                  right: 5,
                  bottom: 5,
                  child: _buildLabelerController(provider),
                )
              ],
            ),
          )
        : Container(
            color: app.colors.greyBackGround,
            child: Column(children: [
              Container(
                width: MediaQuery.of(context).size.width,
                constraints: BoxConstraints(minHeight: 200),
                padding: EdgeInsets.symmetric(horizontal: 30, vertical: 40),
                child: Center(
                  child: Text(
                    provider.getCurrentContent(),
                    style: AppStyles.headline2,
                    maxLines:
                        ResponsiveHelper(context).isSmallScreen ? 5 : null,
                  ),
                ),
              ),
              Padding(
                padding: const EdgeInsets.fromLTRB(5, 0, 5, 5),
                child: _buildLabelerController(provider),
              ),
            ]),
          );
  }

  Widget _buildLabelerController(ProjectProvider provider) {
    _focusNode.requestFocus();
    return KeyboardListener(
      focusNode: _focusNode,
      onKeyEvent: provider.handleLabelKeyboardEvents,
      child: Column(
        children: [
          Wrap(
            spacing: 5,
            runSpacing: 5,
            direction: Axis.vertical,
            children: List.generate(
              provider.getLabelOptions().length,
              (index) => InkWell(
                onTap: () => provider.handleSelectLabel(index),
                child: Container(
                  padding: EdgeInsets.symmetric(horizontal: 12, vertical: 8),
                  margin: EdgeInsets.symmetric(vertical: 2),
                  decoration: BoxDecoration(
                      color: provider.isCurrentLabelSelected(index)
                          ? app.colors.brandOrange
                          : app.colors.white,
                      borderRadius: BorderRadius.all(Radius.circular(20))),
                  child: Row(
                    children: [
                      Text(
                        provider.getLabel(index).get('name') ?? '<NO LABEL>',
                        style: AppStyles.bodyText1.copyWith(
                            color: provider.isCurrentLabelSelected(index)
                                ? app.colors.white
                                : app.colors.brandBlack),
                      ),
                      SizedBox(width: 5),
                      Text(
                        (index + 1).toString(),
                        style: AppStyles.smallCaps.copyWith(
                            color: provider.isCurrentLabelSelected(index)
                                ? app.colors.white.withOpacity(0.5)
                                : app.colors.brandGreyText),
                      ),
                    ],
                  ),
                ),
              ),
            ),
          ),
          Row(
            children: [
              TextButton(
                onPressed: () => provider.handleLabelPrevious(),
                style: tertiaryButtonStyle,
                child: app.icons.arrowLeft(),
              ),
              Spacer(),
              TextButton(
                onPressed: provider.handleLabelNext,
                child: SizedBox(
                  height: 36,
                  child: Row(
                    mainAxisSize: MainAxisSize.min,
                    children: const [Text('Skip item')],
                  ),
                ),
                style: secondaryButtonStyle,
              ),
              Spacer(),
              TextButton(
                onPressed: provider.handleLabelNext,
                style: tertiaryButtonStyle,
                child: app.icons.arrow(),
              )
            ],
          ),
        ],
      ),
    );
  }

  Widget _buildTitleTile(ProjectProvider provider) {
    return ResponsiveHelper(context).isLargeScreen
        ? Row(
            children: [
              Text('Label your data', style: AppStyles.headline1),
              Spacer(),
              _buildBackButton(provider),
              SizedBox(width: 10),
              _buildSubmitButton(provider),
            ],
          )
        : Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Text('Label your data', style: AppStyles.headline1),
              SizedBox(height: 20),
              Row(
                mainAxisAlignment: MainAxisAlignment.end,
                children: [
                  _buildBackButton(provider),
                  SizedBox(width: 20),
                  _buildSubmitButton(provider),
                ],
              ),
            ],
          );
  }

  TextButton _buildSubmitButton(ProjectProvider provider) {
    return TextButton(
      onPressed: () => provider.handleSubmitButton(context),
      style: primaryButtonStyle,
      child: SizedBox(
        height: 36,
        child: Row(
          children: [
            Text('Quit Labeling'),
            SizedBox(width: 10),
            app.icons.arrow()
          ],
        ),
      ),
    );
  }

  TextButton _buildBackButton(ProjectProvider provider) {
    return TextButton(
      onPressed: () => provider.handleResumeSetup(context),
      style: secondaryButtonStyle,
      child: SizedBox(
        height: 36,
        child: Row(
          mainAxisSize: MainAxisSize.min,
          children: const [Text('Back to labeling setup')],
        ),
      ),
    );
  }

  Widget _buildSummary() {
    return Consumer<ProjectProvider>(
      builder: (context, provider, _) {
        return !ResponsiveHelper(context).isSmallScreen
            ? Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  _buildSummaryItems(provider),
                  SizedBox(height: 32),
                  _buildSummaryLabels(provider),
                  // SizedBox(height: 32),
                  // Text(
                  //   "HISTORY",
                  //   style: AppStyles.smallCaps.copyWith(color: app.colors.brandBlack),
                  // ),
                  // SizedBox(height: 4),
                  // Text(
                  //   "lorem ipsum Dolor sit amet",
                  //   style: AppStyles.bodyBold.copyWith(color: Color(0xff7f7c94)),
                  // ),
                ],
              )
            : Row(
                mainAxisAlignment: MainAxisAlignment.spaceAround,
                children: [
                  _buildSummaryItems(provider),
                  _buildSummaryLabels(provider),
                ],
              );
      },
    );
  }

  Widget _buildSummaryItems(ProjectProvider provider) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(
          'ITEMS',
          style: AppStyles.smallCaps.copyWith(color: app.colors.brandBlack),
        ),
        SizedBox(height: 4),
        Row(
          children: [
            Text(
              'Labeled',
              style: AppStyles.bodyBold.copyWith(color: Color(0xff7f7c94)),
            ),
            SizedBox(width: 8),
            Text(
              provider.currentSummary.numLabeled.toString(),
              style: AppStyles.bodyBold.copyWith(color: app.colors.brandBlack),
            ),
            SizedBox(width: 8),
            Text(
              '${provider.currentSummary.percentageLabeled}%',
              style: AppStyles.smallCaps.copyWith(color: app.colors.brandBlack),
            ),
          ],
        ),
        SizedBox(height: 4),
        Row(
          children: [
            Text(
              'Skipped',
              style: AppStyles.bodyBold.copyWith(color: Color(0xff7f7c94)),
            ),
            SizedBox(width: 8),
            Text(
              provider.currentSummary.numSkipped.toString(),
              style: AppStyles.bodyBold.copyWith(color: app.colors.brandBlack),
            ),
            SizedBox(width: 8),
            Text(
              '${provider.currentSummary.percentageSkipped}%',
              style: AppStyles.smallCaps.copyWith(color: app.colors.brandBlack),
            ),
          ],
        ),
        SizedBox(height: 4),
        Row(
          children: [
            Text(
              'Total dataset',
              style: AppStyles.bodyBold.copyWith(color: Color(0xff7f7c94)),
            ),
            SizedBox(width: 8),
            Text(
              provider.getDatasetSize().toString(),
              style: AppStyles.bodyBold.copyWith(color: app.colors.brandBlack),
            ),
          ],
        ),
      ],
    );
  }

  Widget _buildSummaryLabels(ProjectProvider provider) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(
          'LABELS',
          style: AppStyles.smallCaps.copyWith(color: app.colors.brandBlack),
        ),
        SizedBox(height: 4),
        for (Item label in provider.getLabelOptions())
          Row(
            children: [
              Text(
                label.get('name'),
                style: AppStyles.bodyBold.copyWith(color: Color(0xff7f7c94)),
              ),
              SizedBox(width: 8),
              Text(
                (provider.currentSummary.labelFrequencies[label.get('name')] ??
                        0)
                    .toString(),
                style:
                    AppStyles.bodyBold.copyWith(color: app.colors.brandBlack),
              ),
              SizedBox(width: 8),
              Text(
                "${provider.getLabelPercentage(provider.currentSummary.labelFrequencies[label.get("name")])}%",
                style:
                    AppStyles.smallCaps.copyWith(color: app.colors.brandBlack),
              ),
            ],
          ),
      ],
    );
  }
}
