import 'package:flutter/material.dart';
import 'package:memri/configs/routes/route_navigator.dart';
import 'package:memri/constants/app_styles.dart';
import 'package:memri/providers/labeller_provider.dart';
import 'package:memri/utilities/helpers/app_helper.dart';
import 'package:memri/widgets/scaffold/workspace_scaffold.dart';
import 'package:provider/provider.dart';

class ProjectsSetupLabelEditorScreen extends StatefulWidget {
  const ProjectsSetupLabelEditorScreen({Key? key}) : super(key: key);

  @override
  State<ProjectsSetupLabelEditorScreen> createState() =>
      _ProjectsSetupDataScreenState();
}

class _ProjectsSetupDataScreenState
    extends State<ProjectsSetupLabelEditorScreen> {
  @override
  Widget build(BuildContext context) {
    return WorkspaceScaffold(
      currentItem: NavigationItem.projects,
      child: Consumer<LabellerProvider>(
        builder: (context, provider, _) => Container(
            color: Colors.white,
            padding: EdgeInsets.all(32),
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Text('Step 3', style: AppStyles.headline2),
                Text('Add labels you want to use in your app.',
                    style: AppStyles.headline1),
                SizedBox(height: 32),
                Container(
                  constraints: BoxConstraints(maxWidth: 500),
                  child: Text(
                      'Add the labels you want to use on your data and in your app.  You may only use one label per data item. For example, if you are building a sentiment analysis app, add: positive, negative and neutral to label each message.',
                      style: AppStyles.bodyText1),
                ),
                Text(
                    'Use the index numbers for keyboard shortcuts to help you label at warp speed!',
                    style: AppStyles.bodyText1),
                SizedBox(height: 16),
                Column(
                  children: [
                    for (var i = 0; i < provider.getLabelOptions().length; i++)
                      FittedBox(
                        child: Container(
                            padding: EdgeInsets.all(8),
                            margin: EdgeInsets.symmetric(vertical: 8),
                            decoration: BoxDecoration(
                                color: app.colors.brandWhite,
                                borderRadius:
                                    BorderRadius.all(Radius.circular(20))),
                            child: Row(
                              children: [
                                Text(
                                    provider.getLabelOptions()[i].get('name') ??
                                        '<UNNAMED_LABEL>'),
                                SizedBox(width: 4),
                                Text(i.toString()),
                                InkWell(
                                  child: app.icons.x(),
                                  onTap: () =>
                                      provider.handleRemoveLabelOption(i),
                                )
                              ],
                            )),
                      ),
                  ],
                ),
                Row(
                  children: [
                    Flexible(
                      flex: 1,
                      child: Container(
                          color: Color(0xffF5F5F5),
                          child: TextFormField(
                              onFieldSubmitted: (str) =>
                                  provider.handleNewLabel(userInput),
                              controller: userInput,
                              decoration: InputDecoration(
                                  hintText: 'e.g. positive',
                                  contentPadding:
                                      EdgeInsets.symmetric(horizontal: 10),
                                  border: InputBorder.none,
                                  hintStyle: AppStyles.input))),
                    ),
                    Flexible(
                      flex: 2,
                      child: TextButton(
                        onPressed: () {
                          provider.handleNewLabel(userInput);
                        },
                        style: tertiaryButtonStyle,
                        child: Text('Add new label'),
                      ),
                    )
                  ],
                ),
                SizedBox(height: 16),
                Row(
                  children: [
                    Column(
                      children: [
                        TextButton(
                          onPressed: () =>
                              provider.handleConfirmLabellerSetup(context),
                          style: primaryButtonStyle,
                          child: SizedBox(
                            height: 36,
                            child: Row(
                              mainAxisSize: MainAxisSize.min,
                              children: [
                                Text('Next'),
                                SizedBox(width: 16),
                                app.icons.arrow(),
                              ],
                            ),
                          ),
                        ),
                      ],
                    ),
                    SizedBox(width: 16),
                    Column(
                      children: [
                        TextButton(
                            onPressed: () =>
                                RouteNavigator.navigateBack(context),
                            style: secondaryButtonStyle,
                            child: SizedBox(
                              height: 36,
                              child: Row(
                                mainAxisSize: MainAxisSize.min,
                                children: const [Text('Back to data setup')],
                              ),
                            )),
                      ],
                    )
                  ],
                )
              ],
            )),
      ),
    );
  }

  TextEditingController userInput = TextEditingController();

  @override
  void initState() {
    Provider.of<LabellerProvider>(context, listen: false).initLabellerSetup();
    super.initState();
  }
}
