import 'package:flutter/material.dart';
import 'package:memri/configs/routes/route_navigator.dart';
import 'package:memri/constants/app_styles.dart';
import 'package:memri/core/services/analytics_service.dart';
import 'package:memri/localization/generated/l10n.dart';
import 'package:memri/providers/importer_provider.dart';
import 'package:memri/providers/navigation_provider.dart';
import 'package:memri/providers/pod_provider.dart';
import 'package:memri/utilities/helpers/app_helper.dart';
import 'package:memri/utilities/helpers/responsive_helper.dart';
import 'package:memri/widgets/scaffold/workspace_scaffold.dart';
import 'package:memri/widgets/sticker.dart';
import 'package:provider/provider.dart';

class WorkspaceScreen extends StatefulWidget {
  final bool showMainNavigation;

  const WorkspaceScreen({Key? key, this.showMainNavigation = true})
      : super(key: key);

  @override
  WorkspaceScreenState createState() => WorkspaceScreenState();
}

class WorkspaceScreenState extends State<WorkspaceScreen> {
  late final _navigationProvider =
      Provider.of<NavigationProvider>(context, listen: false);
  late final _importerProvider =
      Provider.of<ImporterProvider>(context, listen: false);
  late final _podProvider = Provider.of<PodProvider>(context, listen: false);

  @override
  void initState() {
    _podProvider.initWorkspace();
    if (_podProvider.state == AuthState.authenticated ||
        _podProvider.state == AuthState.savedKeys) {
      _importerProvider.fetchActiveImporters();
    }
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return WorkspaceScaffold(
      currentItem: NavigationItem.workspace,
      backgroundColor: app.colors.greyBackGround,
      child: SingleChildScrollView(
        child: Container(
          width: MediaQuery.of(context).size.width,
          color: app.colors.greyBackGround,
          padding: EdgeInsets.all(30),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              if (!ResponsiveHelper(context).isSmallScreen)
                SizedBox(height: 16),
              Text(S.current.workspace_title, style: AppStyles.headline1),
              SizedBox(height: 20),
              Text(
                S.current.workspace_description,
                style: AppStyles.bodyText1.copyWith(color: Color(0xff999999)),
              ),
              SizedBox(height: 20),
              Wrap(
                spacing: 4,
                runSpacing: 4,
                children: [
                  Sticker(
                    icon: app.images.signFirst(height: 70),
                    title: S.current.workspace_sticker_1_title,
                    description: S.current.workspace_sticker_1_description,
                    buttonsTitle: [
                      S.current.workspace_sticker_1_button_1_label,
                      S.current.workspace_sticker_1_button_2_label,
                    ],
                    buttonsCallback: [
                      () => RouteNavigator.navigateTo(
                          route: Routes.data, context: context),
                      () => RouteNavigator.navigateTo(
                          route: Routes.importerCreate, context: context),
                    ],
                  ),
                  Sticker(
                    icon: app.images.signSecond(height: 70),
                    title: S.current.workspace_sticker_2_title,
                    description: S.current.workspace_sticker_2_description,
                    buttonsTitle: [
                      S.current.workspace_sticker_2_button_1_label
                    ],
                    buttonsCallback: [
                      () => RouteNavigator.navigateTo(
                          route: Routes.projectsCreate, context: context)
                    ],
                  ),
                  Sticker(
                    icon: app.images.signThird(height: 70),
                    title: S.current.workspace_sticker_3_title,
                    description: S.current.workspace_sticker_3_description,
                    disabled: true,
                    buttonsTitle: [
                      S.current.workspace_sticker_3_button_1_label
                    ],
                    buttonsCallback: [
                      () => AnalyticsService()
                          .logNavigationButton(AnalyticsEvents.customizeApp),
                    ],
                  ),
                  Sticker(
                    icon: app.images.signFourth(height: 70),
                    title: S.current.workspace_sticker_4_title,
                    description: S.current.workspace_sticker_4_description,
                    buttonsTitle: [
                      S.current.workspace_sticker_4_button_1_label,
                      S.current.workspace_sticker_4_button_2_label,
                    ],
                    buttonsCallback: [
                      _navigationProvider.openGuideLink,
                      _navigationProvider.openDiscordLink,
                    ],
                  ),
                ],
              ),
            ],
          ),
        ),
      ),
    );
  }
}
