import 'package:flutter/material.dart';
import 'package:memri/core/models/item.dart';
import 'package:memri/providers/data_app_provider.dart';
import 'package:memri/utilities/extensions/date_time.dart';
import 'package:memri/utilities/helpers/app_helper.dart';
import 'package:memri/widgets/data_app/data_app_row.dart';
import 'package:provider/provider.dart';

class DataAppList extends StatefulWidget {
  const DataAppList({Key? key, required this.contents}) : super(key: key);

  final List<Item> contents;

  @override
  State<DataAppList> createState() => _DataAppListState();
}

class _DataAppListState extends State<DataAppList> {
  Set<String> labels = {};
  final List<Color> labelColors = [
    app.colors.brandViolet,
    app.colors.brandOrange,
    app.colors.brandLineGrey,
    app.colors.brandGreen,
    app.colors.brandPurple,
    app.colors.brandYellow,
    app.colors.brandBlue,
  ];

  @override
  Widget build(BuildContext context) {
    return Consumer<DataAppProvider>(builder: (context, provider, _) {
      return Column(
        children: List.generate(
          widget.contents.length,
          (index) {
            var message = widget.contents[index];
            var label = message.edgeItem('label')?.get('value');
            if (!labels.contains(label)) labels.add(label);
            int labelIndex = 0;
            for (int i = 0; i < labels.length; i++) {
              if (labels.elementAt(i) == label) {
                labelIndex = i;
                break;
              }
            }
            return DataAppRow(
                content: message.get('content') ?? '[NO CONTENT]',
                date: formatTimestamp(message.get('dateSent')).toString(),
                label: label ?? '',
                labelColor: labelColors[labelIndex]);
          },
        ),
      );
    });
  }

  String formatTimestamp(int? timestamp) {
    if (timestamp != null) {
      return DateTime.fromMillisecondsSinceEpoch(timestamp)
          .formatted(dateFormat: 'yyyy/MM/dd')
          .toString();
    }
    return '';
  }
}
