import 'package:flutter/material.dart';
import 'package:memri/constants/app_styles.dart';
import 'package:memri/core/models/item.dart';
import 'package:memri/providers/data_app_provider.dart';
import 'package:memri/utilities/helpers/app_helper.dart';
import 'package:provider/provider.dart';

class DataAppTile extends StatefulWidget {
  const DataAppTile({Key? key, required this.dataApp}) : super(key: key);

  final Item dataApp;

  @override
  State<DataAppTile> createState() => _DataAppTileState();
}

class _DataAppTileState extends State<DataAppTile> {
  @override
  Widget build(BuildContext context) {
    var name = widget.dataApp.get('name') ?? 'Unnamed';
    var status = widget.dataApp.get('status') ?? '';
    var description = widget.dataApp.get('pluginDescription') ?? '';
    return Consumer<DataAppProvider>(builder: (context, provider, _) {
      return InkWell(
        onTap: () => provider.handleOpenDataApp(
            context, widget.dataApp, AppState.showApp),
        child: Container(
          color: Color(0xfff0f0f0),
          padding: EdgeInsets.all(20),
          child: Column(
            mainAxisSize: MainAxisSize.min,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Row(
                children: [
                  Text(name, style: AppStyles.headline2),
                  Spacer(),
                  Text(status,
                      style: AppStyles.bodyText1
                          .copyWith(color: Color(0xff15B599))),
                ],
              ),
              if (description.isNotEmpty) SizedBox(height: 45),
              if (description.isNotEmpty)
                Text(
                  description,
                  style: AppStyles.bodyText1
                      .copyWith(color: app.colors.brandGreyText),
                ),
              SizedBox(height: 30),
              Row(
                children: [
                  TextButton(
                    style: ButtonStyle(
                        padding: MaterialStateProperty.all(EdgeInsets.all(0))),
                    onPressed: () => provider.handleOpenDataApp(
                        context, widget.dataApp, AppState.showApp),
                    child: Text(
                      'Open App',
                      style: AppStyles.buttonLabel
                          .copyWith(color: app.colors.primary),
                    ),
                  ),
                  SizedBox(width: 20),
                  TextButton(
                    style: ButtonStyle(
                        padding: MaterialStateProperty.all(EdgeInsets.all(0))),
                    onPressed: () => provider.handleOpenDataApp(
                        context, widget.dataApp, AppState.showSettings),
                    child: Text(
                      'Settings',
                      style: AppStyles.buttonLabel
                          .copyWith(color: app.colors.black),
                    ),
                  ),
                  Spacer(),
                  TextButton(
                    style: ButtonStyle(
                        padding: MaterialStateProperty.all(EdgeInsets.all(0))),
                    onPressed: () => provider.handleOpenDataApp(
                        context, widget.dataApp, AppState.showLogs),
                    child: Text(
                      'Logs',
                      style: AppStyles.buttonLabel
                          .copyWith(color: app.colors.black),
                    ),
                  ),
                ],
              ),
            ],
          ),
        ),
      );
    });
  }
}
