import 'package:flutter/material.dart';
import 'package:memri/constants/app_styles.dart';
import 'package:memri/providers/oauth_provider.dart';
import 'package:memri/utilities/helpers/responsive_helper.dart';
import 'package:memri/widgets/screen_error.dart';
import 'package:provider/provider.dart';

class ImporterConnectTwitter extends StatelessWidget {
  const ImporterConnectTwitter({Key? key, required this.parentContext})
      : super(key: key);

  final BuildContext parentContext;

  @override
  Widget build(BuildContext context) {
    return Consumer<OAuthProvider>(builder: (context, provider, _) {
      return provider.whatsappStatus == 'error'
          ? ScreenError(
              title: 'Twitter importer failed to load your data.',
              message:
                  'Twitter importer failed to load your data. Please try again.',
            )
          : Column(
              mainAxisAlignment: MainAxisAlignment.start,
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                SizedBox(height: 20),
                if (!ResponsiveHelper(context).isSmallScreen)
                  SizedBox(height: 20),
                Text('Authorise twitter access', style: AppStyles.headline1),
                SizedBox(height: 10),
                ConstrainedBox(
                  constraints: BoxConstraints(maxWidth: 650),
                  child: Text(
                    'To be able to connect Twitter to your POD, you need to authorize your Twitter account. This is done via Twitter directly so Memri will not have access to your credentials. You can deauthorize Memri at any time via your Twitter account. ',
                    style: AppStyles.bodyText1,
                  ),
                ),
                SizedBox(height: 30),
                TextButton(
                    onPressed: () => provider.initTwitterOAuth(parentContext),
                    child:
                        Text('Authorise Twitter', style: AppStyles.buttonLabel),
                    style: tertiaryButtonStyle),
                SizedBox(height: 20),
                if (!ResponsiveHelper(context).isSmallScreen)
                  SizedBox(height: 20),
              ],
            );
    });
  }
}
