import 'package:flutter/material.dart';
import 'package:memri/configs/routes/route_navigator.dart';
import 'package:memri/constants/app_styles.dart';
import 'package:memri/utilities/helpers/app_helper.dart';
import 'package:memri/utilities/helpers/responsive_helper.dart';

class ScreenError extends StatelessWidget {
  const ScreenError({
    Key? key,
    required this.title,
    required this.message,
    this.buttonLabel = 'Back',
    this.onButtonPressed,
  }) : super(key: key);

  final String title;
  final String message;
  final String buttonLabel;
  final VoidCallback? onButtonPressed;

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        SizedBox(height: 20),
        if (!ResponsiveHelper(context).isSmallScreen) SizedBox(height: 20),
        Text(
          'Something went wrong :(',
          style: AppStyles.link.copyWith(color: app.colors.brandOrange),
        ),
        Text(
          title,
          style: AppStyles.headline1.copyWith(color: app.colors.brandOrange),
        ),
        SizedBox(height: 10),
        Text(
          message,
          style: AppStyles.bodyText1,
        ),
        SizedBox(height: 80),
        TextButton(
          onPressed:
              onButtonPressed ?? () => RouteNavigator.navigateBack(context),
          style: secondaryButtonStyle,
          child: SizedBox(
            height: 36,
            child: Row(
              mainAxisSize: MainAxisSize.min,
              children: [
                app.icons.back(color: app.colors.brandOrange),
                SizedBox(width: 10),
                Text(buttonLabel),
              ],
            ),
          ),
        ),
        SizedBox(height: 20),
        if (!ResponsiveHelper(context).isSmallScreen) SizedBox(height: 20),
      ],
    );
  }
}
